(exercise1 d e f)Will someone ever link to me?
Will someone ever link to me?
(exercise2)A docstring can contain CommonMark formatted text.
Lists
Blockquotes
A quote
a nested quote
a very nested quote
Paragraphs
If you want a paragraph to include a linebreak,
you can do that.
Tables
Tables are a CommonMark extension but supported by cljdoc
| Left | Centered | Right |
|---|---|---|
| lets | peanut butter | 100 |
| fill | and | 10 |
| this | pickles | 1 |
Code blocks
(defn exercise
"A docstring can contain CommonMark formatted text."
[]
(+ 4 5 6))
Links
For more more options see the markdown features article.
Wikilinks
Wikilinks are a cljdoc extension and allow you to link to api functions. They only work in docstrings.
Let's link to the exercise1 function in this namespace.
**A docstring can contain CommonMark formatted text.**
**Lists**
1. one
2. two
- buckle
- my
- shoe
**Blockquotes**
> A quote
>> a nested quote
>>> a very nested quote
**Paragraphs**
If you want a paragraph to include a linebreak, \
you can do that.
**Tables**
Tables are a CommonMark extension but supported by cljdoc
| Left | Centered | Right |
|----------|:-------------:|------:|
| lets | peanut butter | 100 |
| fill | and | 10 |
| this | pickles | 1 |
**Code blocks**
```clojure
(defn exercise
"A docstring can contain CommonMark formatted text."
[]
(+ 4 5 6))
```
**Links**
For more more options see
[the markdown features article](https://cljdoc.org/d/lread/cljdoc-exerciser/CURRENT/doc/tests/md-features.md).
**Wikilinks**
Wikilinks are a cljdoc extension and allow you to link to api functions.
They only work in docstrings.
Let's link to the [[exercise1]] function in this namespace.(exercise3 x y z)Linking to images might be of interest, I suppose.
Will one of my local images show up? I certainly hope so.
An external image should work fine too:
Linking to images might be of interest, I suppose. Will one of my local images show up? I certainly hope so.  An external image should work fine too: 
(exercise4 a b c)Using headings in a docstring might be ridiculous, but you can do it.
this is too much, I am heading home.
Using headings in a docstring might be ridiculous, but you can do it. # Heading 1 ## Heading 2 ### Heading 3 #### Heading 4 ##### Heading 5 this is too much, I am heading home.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |